==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/AssigningShapeStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningShapeStyleEventArgsDescription } from "./AssigningShapeStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningShapeStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningShapeStyleEventArgsDescriptionMetadata, _super);
    function AssigningShapeStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningShapeStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningShapeStyleEventArgsDescriptionMetadata.a == null) {
            AssigningShapeStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningShapeStyleEventArgsDescriptionMetadata.c(AssigningShapeStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningShapeStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningShapeStyleEventArgsDescriptionMetadata.a);
    };
    AssigningShapeStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningShapeStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningShapeStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningShapeStyleEventArgs", function () { return new AssigningShapeStyleEventArgsDescription(); });
        a.z("AssigningShapeStyleEventArgs", AssigningShapeStyleEventArgsDescriptionMetadata.a);
    };
    AssigningShapeStyleEventArgsDescriptionMetadata.$t = markType(AssigningShapeStyleEventArgsDescriptionMetadata, 'AssigningShapeStyleEventArgsDescriptionMetadata');
    AssigningShapeStyleEventArgsDescriptionMetadata.a = null;
    return AssigningShapeStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningShapeStyleEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningShapeStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningShapeStyleEventArgsDescription } from "./AssigningShapeStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningShapeStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningShapeStyleEventArgsDescriptionMetadata, _super);
    function AssigningShapeStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningShapeStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningShapeStyleEventArgsDescriptionMetadata.a == null) {
            AssigningShapeStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningShapeStyleEventArgsDescriptionMetadata.c(AssigningShapeStyleEventArgsDescriptionMetadata.a);
        }
        if (a.k(AssigningShapeStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningShapeStyleEventArgsDescriptionMetadata.a);
    };
    AssigningShapeStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningShapeStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningShapeStyleEventArgsDescriptionMetadata.b(a);
        a.ac("AssigningShapeStyleEventArgs", function () { return new AssigningShapeStyleEventArgsDescription(); });
        a.ab("AssigningShapeStyleEventArgs", AssigningShapeStyleEventArgsDescriptionMetadata.a);
    };
    AssigningShapeStyleEventArgsDescriptionMetadata.$t = markType(AssigningShapeStyleEventArgsDescriptionMetadata, 'AssigningShapeStyleEventArgsDescriptionMetadata');
    AssigningShapeStyleEventArgsDescriptionMetadata.a = null;
    return AssigningShapeStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningShapeStyleEventArgsDescriptionMetadata };
